## dbt-snowflake 1.10.2 - September 09, 2025

### Fixes

- fix table and column descriptions for snowflake iceberg tables ([#1015](https://github.com/dbt-labs/dbt-adapters/issues/1015))

### Dependencies

- bump dbt-adapters version pin floor to >=1.16.6  ([#1328](https://github.com/dbt-labs/dbt-adapters/pull/1328))

### Contributors
- [@sandeepmullangi2](https://github.com/sandeepmullangi2) ([#1015](https://github.com/dbt-labs/dbt-adapters/issues/1015))
